
dialogId("dlg-x-poster1", "font_poster", "Greetings from the rubbish heap to our beloved boss.")
dialogStr("Salutations depuis le tas d'immondices ŕ notre patron bien-aimé.")


dialogId("dlg-x-poster2", "font_poster", "Yours sincerely")
dialogStr("Vos trčs dévoués")


dialogId("dlg-x-poster3", "font_poster", "Agents")
dialogStr("Agents")


dialogId("dlg-x-poster4", "font_poster", "PS: It's great to be here. We irradiate ourselves and swim in the sea a lot. We have many new friends.")
dialogStr("PS: C'est formidable d'ętre ici. Nous nous sommes irradiés et nous nageons beaucoup. Nous avons beaucoup de nouveaux amis.")

